using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace BYOJeopardy_net
{
    public partial class FormMain : Form
    {
        public static JData jeopardydata = new JData();
        public static bool AnswerasQuestion = true;
        public static string FileName = "";
        public FormMain()
        {
            InitializeComponent();
            tableLayoutPanel1.Hide();

            for (int n = 0; n <= System.Environment.GetCommandLineArgs().Length - 1; n++)
            {
                Console.WriteLine(System.Environment.GetCommandLineArgs()[n].ToString());
                if (System.IO.Path.GetExtension(System.Environment.GetCommandLineArgs()[n].ToString()) == ".byj")
                {
                    OpenBYOJFile(System.Environment.GetCommandLineArgs()[n].ToString());
                }
            }
        }

        private void newToolStripMenuItem_Click(object sender, EventArgs e)
        {
            FormTemplate frmTemplate = new FormTemplate();
            if(frmTemplate.ShowDialog() == DialogResult.OK)
            {
                FileName = "";
                FormEdit frmEdit = new FormEdit();
                if(frmTemplate.rbtnSingle.Checked | frmTemplate.rbtnDouble.Checked)
                {
                    jeopardydata.CreateJeopardy(frmTemplate.rbtnDouble.Checked);
                    frmEdit.FillTreeView();
                }
                frmEdit.Show();
            }
        }
        FormEdit frmEdit;
        private void editToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (frmEdit == null)
            {
                frmEdit = new FormEdit();
                frmEdit.FillTreeView();
                frmEdit.Show();
            }
            else
            {
                frmEdit.Activate();
            }
            
        }

        private void openToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (this.openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                OpenBYOJFile(this.openFileDialog1.FileName);
            }
            //Canceled opening
        }

        private void reloadtoolStripMenuItem_Click(object sender, EventArgs e)
        {
            OpenBYOJFile(FormMain.FileName);
        }

        private void OpenBYOJFile(string FileNameStr)
        {
            FormFormat Format = new FormFormat();
            this.Text = "Build Your Own Jeopardy -- " + this.openFileDialog1.FileName;
            this.editToolStripMenuItem.Enabled = true;
            this.reloadtoolStripMenuItem.Enabled = true;

            FileName = FileNameStr;
            if (Format.ShowDialog() == DialogResult.OK)
            {
                AnswerasQuestion = Format.AnswerasQuestion.Checked;
                Format.Dispose();
                ClearScreen();
                if (jeopardydata.OpenFile(FileNameStr))
                {
                    buildBoard();
                    return;
                }
                else
                {
                    //add Error Dialog
 
                }
            }
            else
            {
                return;
            }
            //File not opened
            this.Text = "Build Your Own Jeopardy";
            FileName = "";
            this.editToolStripMenuItem.Enabled = false;
            this.reloadtoolStripMenuItem.Enabled = false;
            tableLayoutPanel1.Hide();
        }

        private void ClearScreen()
        {
            tableLayoutPanel1.Hide();
            tableLayoutPanel1.Controls.Clear();    
        }

        private void buildBoard()
        {
            //tableLayoutPanel1 = new TableLayoutPanel();
            tableLayoutPanel1.Hide();
            tableLayoutPanel1.BackColor = System.Windows.Forms.Control.DefaultBackColor;  
            tableLayoutPanel1.ColumnCount = jeopardydata.topics.Count;
            
            ///find Daily Double
            int daily_double_count = 0;
            int topics_count = jeopardydata.topics.Count;
            string daily_double_value = "";
            string daily_double_question = "";
            string daily_double_answer = "";

            for (int c = 0; c < jeopardydata.topics.Count; c++)
            {
                JTopic topic = (JTopic)jeopardydata.topics[c];
                if (topic.TopicName.ToLower() == "daily double")
                {
                    topics_count -= 1;
                    if(topic.Values.Count > 0)
                    {
                        daily_double_value = topic.Values[0].ToString();
                    }
                    if(topic.Questions.Count > 0)
                    {
                        daily_double_question = topic.Questions[0].ToString();
                    }
                    if(topic.Answers.Count > 0)
                    {
                        daily_double_answer = topic.Answers[0].ToString();
                    }
                }
                else
                {
                    daily_double_count += topic.Values.Count;
                }
            }
            ///set random Daily Double 
            Console.WriteLine("Daily Double Count: " + daily_double_count); 
            Random randy = new Random(0);
            int daily_double = UpperBoundRandoms (daily_double_count - 1);
            Console.WriteLine("Daily Double: " + daily_double);

            ///build board
            daily_double_count = 0;  //reset to find daily double
            for (int c = 0; c < topics_count; c++)
            {
                if (tableLayoutPanel1.ColumnStyles.Count <= c)
                {
                    ColumnStyle cStyle = new ColumnStyle();
                    tableLayoutPanel1.ColumnStyles.Add(cStyle);
                }
                JTopic topic = (JTopic)jeopardydata.topics[c];
                if (topic.TopicName.ToLower() != "daily double")
                {
                    if (tableLayoutPanel1.RowCount < topic.Values.Count + 1)
                    {
                        tableLayoutPanel1.RowCount = topic.Values.Count + 1;
                    }
                    JLabel lbTopic = new JLabel();
                    lbTopic.Text = topic.TopicName;
                    tableLayoutPanel1.Controls.Add(lbTopic, c, 0);
                    for (int r = 0; r < topic.Values.Count; r++)
                    {
                        JButton btnValue = new JButton();
                        btnValue.Dock = DockStyle.Fill;
                        btnValue.button.Text = topic.Values[r].ToString();
                        if (daily_double_count == daily_double && daily_double_question != "")
                        {
                            btnValue.Topic = daily_double_value;
                            btnValue.Question = daily_double_question;
                            btnValue.Answer = daily_double_answer;
                            btnValue.Daily_Double = true;
                        }
                        else
                        {
                            btnValue.Topic = topic.TopicName;
                            if (r < topic.Questions.Count)
                            {
                                btnValue.Question = (string)topic.Questions[r];
                            }
                            if (r < topic.Answers.Count)
                            {
                                btnValue.Answer = (string)topic.Answers[r];
                            }
                        }
                        tableLayoutPanel1.Controls.Add(btnValue, c, r + 1);
                        daily_double_count += 1;
                    }
                }
             }
            SizeRows();
            SizeCols();
            tableLayoutPanel1.Show();
        }

        // Generate random numbers with an upper bound specified.
        static int UpperBoundRandoms(int upper)
        {
            // Wait to allow the timer to advance.
            System.Threading.Thread.Sleep(1);

            Random randy = new Random();
            Double randyD = randy.NextDouble();
            int random_number = (int)(randyD * upper);  
            return randy.Next(upper);
        }

        private void SizeRows()
        {
            TableLayoutRowStyleCollection styles = this.tableLayoutPanel1.RowStyles;

            foreach (RowStyle style in styles)
            {
                style.SizeType = SizeType.Percent;
                style.Height = 100 /styles.Count;                  
            }
        }
        private void SizeCols()
        {
            TableLayoutColumnStyleCollection styles = this.tableLayoutPanel1.ColumnStyles;

            foreach (ColumnStyle style in styles)
            {
                style.SizeType = SizeType.Percent;
                style.Width = 100 / styles.Count;  
            }
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void aboutToolStripMenuItem_Click(object sender, EventArgs e)
        {
            AboutBox1 frmAbout = new AboutBox1();
            frmAbout.ShowDialog(); 
        }


        //protected override void OnMouseClick(System.Windows.Forms.MouseEventArgs e)
        //{
        //    System.Console.WriteLine("Musa Clicked Main");
        //}

        //private void tableLayoutPanel1_Click(object sender, EventArgs e)
        //{
        //    object tableobj = this.tableLayoutPanel1.GetChildAtPoint(MousePosition);
        //    if (tableobj.GetType() == Type.GetType("JButton"))
        //    {
        //        Console.WriteLine("Goh");
        //    }
        //}


    }
}